Multiple regression for parcel data
dual_reg_parc(
BOLD,
parc,
parc_vals,
scale = c("local", "global", "none"),
scale_sm_xifti = NULL,
scale_sm_FWHM = 2,
TR = NULL,
hpf = 0.01,
GSR = FALSE
)A list containing the subject-level independent components S (\(Q \times V\)), and subject-level mixing matrix A (\(TxQ\)).
Subject-level fMRI data matrix (\(V \times T\)). Rows will be centered.
The parcellation as an integer vector.
The parcel values (keys) in desired order, e.g.
sort(unique(parc)).
"local" (default), "global", or "none".
Local scaling will divide each data location's time series by its estimated
standard deviation. Global scaling will divide the entire data matrix by the
mean image standard deviation (mean(sqrt(rowVars(BOLD)))).
Only applies if scale=="local" and
BOLD represents CIFTI-format data. To smooth the standard deviation
estimates used for local scaling, provide a "xifti" object with data
locations in alignment with BOLD, as well as the smoothing FWHM
(default: 2). If no "xifti" object is provided (default), do
not smooth.
The temporal resolution of the data, i.e. the time between volumes,
in seconds. TR is required for detrending with hpf.
The frequency at which to apply a highpass filter to the data
during pre-processing, in Hertz. Default: 0.01 Hertz. Set to 0
to disable the highpass filter.
The highpass filter serves to detrend the data, since low-frequency variance is associated with noise. Highpass filtering is accomplished by nuisance regression of discrete cosine transform (DCT) bases.
Note the TR argument is required for highpass filtering. If
TR is not provided, hpf will be ignored.
Center BOLD across columns (each image)? This
is equivalent to performing global signal regression. Default:
FALSE.