Learn R Programming

fMRItools (version 0.7.2)

skew_pos: Positive skew?

Description

Does the vector have a positive skew?

Usage

skew_pos(x)

Value

TRUE if the skew is positive or zero. FALSE if the skew is negative.

Arguments

x

The numeric vector for which to calculate the skew. Can also be a matrix, in which case the skew of each column will be calculated.