powered by
Does the vector have a positive skew?
skew_pos(x)
TRUE if the skew is positive or zero. FALSE if the skew is negative.
TRUE
FALSE
The numeric vector for which to calculate the skew. Can also be a matrix, in which case the skew of each column will be calculated.